@@ -3,7 +3,7 @@ use strict;
 use warnings;
 
 my $i = 0;
-while ( my @call = caller($i) ) {
+while ( my @call = map { defined($_) ? $_ : "undef" } caller($i) ) {
     print "$i @call[0..7]\n";
     $i++;
 }
